==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesExtensionOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property resourceCreationBegin
 */
public data class ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
    public val resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder()
            .resourceCreationBegin(
                resourceCreationBegin?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesExtensionOptionsArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesExtensionOptionsArgsBuilder internal constructor() {
    private var resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("hgrivbykmpibydqs")
    public suspend
    fun resourceCreationBegin(`value`: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>) {
        this.resourceCreationBegin = value
    }

    /**
     * @param value
     */
    @JvmName("ojbdgibpsreokdwy")
    public suspend
    fun resourceCreationBegin(`value`: ResourceTypeExtensionOptionsResourceCreationBeginArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceCreationBegin = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ibnoocqribyuscix")
    public suspend
    fun resourceCreationBegin(argument: suspend ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.resourceCreationBegin = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
            resourceCreationBegin = resourceCreationBegin,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/ResourceTypeRegistrationPropertiesExtensionOptionsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property resourceCreationBegin
 */
public data class ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
    public val resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null,
) :
    ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs> {
    override fun toJava():
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        com.pulumi.azurenative.providerhub.inputs.ResourceTypeRegistrationPropertiesExtensionOptionsArgs.builder()
            .resourceCreationBegin(
                resourceCreationBegin?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [ResourceTypeRegistrationPropertiesExtensionOptionsArgs].
 */
@PulumiTagMarker
public class ResourceTypeRegistrationPropertiesExtensionOptionsArgsBuilder internal constructor() {
    private var resourceCreationBegin: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>? =
        null

    /**
     * @param value
     */
    @JvmName("hkdppnlqdvfaafef")
    public suspend
    fun resourceCreationBegin(`value`: Output<ResourceTypeExtensionOptionsResourceCreationBeginArgs>) {
        this.resourceCreationBegin = value
    }

    /**
     * @param value
     */
    @JvmName("xmidamcpqlofmrgo")
    public suspend
    fun resourceCreationBegin(`value`: ResourceTypeExtensionOptionsResourceCreationBeginArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceCreationBegin = mapped
    }

    /**
     * @param argument
     */
    @JvmName("bppsjmqbvcvaiqod")
    public suspend
    fun resourceCreationBegin(argument: suspend ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder.() -> Unit) {
        val toBeMapped = ResourceTypeExtensionOptionsResourceCreationBeginArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.resourceCreationBegin = mapped
    }

    internal fun build(): ResourceTypeRegistrationPropertiesExtensionOptionsArgs =
        ResourceTypeRegistrationPropertiesExtensionOptionsArgs(
            resourceCreationBegin = resourceCreationBegin,
        )
}
